# PPxF Assistant

### Description
This package is designed to assist in the application of the PPxF method to Integrated Field Spectra (IFS), to be able to
extract the internal kinematics of galaxies. One major focus
of this package is to make the process more interactive so that
the user has a better grasp of what is being done.